summaryrefslogtreecommitdiff
path: root/storage/connect/tabdos.h
diff options
context:
space:
mode:
authorOlivier Bertrand <bertrandop@gmail.com>2016-12-14 14:20:23 +0100
committerOlivier Bertrand <bertrandop@gmail.com>2016-12-14 14:20:23 +0100
commit952306502ebf1b26c627c5dc8b141581eeb30671 (patch)
tree571d99c7035ad62c489f88ead60e5cbf32a14a9e /storage/connect/tabdos.h
parentd44723e62153d9fb4165d038e9448c20a3ad890b (diff)
downloadmariadb-git-952306502ebf1b26c627c5dc8b141581eeb30671.tar.gz
- MDEV-11295: developing handling files contained in ZIP file.
Enable using multiple zip files modified: storage/connect/filamzip.cpp modified: storage/connect/ha_connect.cc modified: storage/connect/ha_connect.h modified: storage/connect/mycat.h modified: storage/connect/tabdos.cpp modified: storage/connect/tabdos.h modified: storage/connect/tabfmt.cpp modified: storage/connect/tabjson.cpp
Diffstat (limited to 'storage/connect/tabdos.h')
-rw-r--r--storage/connect/tabdos.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/storage/connect/tabdos.h b/storage/connect/tabdos.h
index 501ddbc2e0b..623adcfed0d 100644
--- a/storage/connect/tabdos.h
+++ b/storage/connect/tabdos.h
@@ -59,7 +59,7 @@ class DllExport DOSDEF : public TABDEF { /* Logical table description */
// Methods
virtual int Indexable(void)
- {return (!Multiple && !Zipfn && Compressed != 1) ? 1 : 0;}
+ {return (!Multiple && !Zipped && Compressed != 1) ? 1 : 0;}
virtual bool DeleteIndexFile(PGLOBAL g, PIXDEF pxdf);
virtual bool DefineAM(PGLOBAL g, LPCSTR am, int poff);
virtual PTDB GetTable(PGLOBAL g, MODE mode);
@@ -73,11 +73,12 @@ class DllExport DOSDEF : public TABDEF { /* Logical table description */
// Members
PSZ Fn; /* Path/Name of corresponding file */
PSZ Ofn; /* Base Path/Name of matching index files*/
- PSZ Zipfn; /* Zip container name */
+ PSZ Entry; /* Zip entry name or pattern */
PIXDEF To_Indx; /* To index definitions blocks */
RECFM Recfm; /* 0:VAR, 1:FIX, 2:BIN, 3:VCT, 6:DBF */
bool Mapped; /* 0: disk file, 1: memory mapped file */
- bool Padded; /* true for padded table file */
+ bool Zipped; /* true for zipped table file */
+ bool Padded; /* true for padded table file */
bool Huge; /* true for files larger than 2GB */
bool Accept; /* true if wrong lines are accepted */
bool Eof; /* true if an EOF (0xA) character exists */